"use strict";
// Licensed to the Software Freedom Conservancy (SFC) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The SFC licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.opts = exports.displayName = void 0;
const side_code_export_1 = require("side-code-export");
const command_1 = __importDefault(require("./command"));
const location_1 = __importDefault(require("./location"));
const hook_1 = __importDefault(require("./hook"));
// Define language options
exports.displayName = 'Java JUnit';
exports.opts = {
    emitter: command_1.default,
    displayName: exports.displayName,
    name: 'java-junit',
    hooks: (0, side_code_export_1.generateHooks)(hook_1.default),
    fileExtension: '.java',
    commandPrefixPadding: '  ',
    terminatingKeyword: '}',
    commentPrefix: '//',
    generateFilename: (name) => {
        return `${side_code_export_1.codeExport.parsers.capitalize(side_code_export_1.codeExport.parsers.sanitizeName(name))}Test${exports.opts.fileExtension}`;
    },
    generateMethodDeclaration: (name) => {
        return `public void ${side_code_export_1.codeExport.parsers.sanitizeName(name)}() {`;
    },
    // Create generators for dynamic string creation of primary entities (e.g., filename, methods, test, and suite)
    generateSuiteDeclaration: (name) => {
        return `public class ${side_code_export_1.codeExport.parsers.capitalize(side_code_export_1.codeExport.parsers.sanitizeName(name))}Test {`;
    },
    generateTestDeclaration: (name) => {
        return `@Test\npublic void ${side_code_export_1.codeExport.parsers.uncapitalize(side_code_export_1.codeExport.parsers.sanitizeName(name))}() {`;
    },
};
exports.default = (0, side_code_export_1.languageFromOpts)(exports.opts, location_1.default.emit);
//# sourceMappingURL=index.js.map